==> order-base-0.4.20-RELEASE-sources.jar: com/rocogz/syy/order/dto/withdrawals/WithdrawalsAdminSearchParamDto.java <==
package com.rocogz.syy.order.dto.withdrawals;

import com.rocogz.syy.order.constant.OrderConstant;
import com.rocogz.syy.order.dto.AdminBaseSearchDto;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;

/**
 * 管理后台-> 提现订单 搜索 条件
 * @author ranxiangfu
 * @date 2020/8/4
 */
@Data
public class WithdrawalsAdminSearchParamDto extends AdminBaseSearchDto  {

    public WithdrawalsAdminSearchParamDto() {
        setOrderType(OrderConstant.DictOrderType.WITHDRAWALS_ORDER);
    }

    /**
     * 收款账户/卡号
     */
    private String account;

    /**
     * 提现状态: PENDIND-待审批; PENDIND_PROCESS-(已受理/待处理); REFUSE-(未受理/审核不通过);
     *      PROCESSING-(转账中/处理中); SUCCESS-提现成功; FAIL-提现失败;
     */
    private String withdrawalsStatus;

    /**
     * 提现方式; ALIPAY:支付宝, BANK:银行账户
     */
    private String withdrawalsWay;

    /**
     * 身份证号码【模糊匹配】
     */
    private String idCard;

    /**
     * 收款人姓名 【模糊匹配】
     * 提现方式：如果是 ALIPAY（支付宝),则用id_name匹配
     * 提现方式：如果是 BANK（银行账户),则用bank_cardholder_name匹配
     */
    private String payeeName;

    /**
     * 收款人手机号码 【模糊匹配】
     */
    private String payeeMobile;

    /**
     * 更新时间起始
     */
    private String updateStartTime;

    /**
     * 更新时间结束
     */
    private String updateEndTime;

    //如果 maxCent!=null,则查询 积分 <= maxCent的提现订单
    private BigDecimal maxCent;



    public String getIdCardLike() {
        if(StringUtils.isBlank(idCard)) {
            return null;
        }
        return StringUtils.wrap(idCard,"%");
    }


    public String getPayeeMobileLike() {
        if(StringUtils.isBlank(payeeMobile)) {
            return null;
        }
        return StringUtils.wrap(payeeMobile,"%");
    }


    public String getPayeeNameLike() {
        if(StringUtils.isBlank(payeeName)) {
            return null;
        }
        return StringUtils.wrap(payeeName,"%");
    }

}

==> order-base-0.4.27-RELEASE-sources.jar: com/rocogz/syy/order/dto/withdrawals/WithdrawalsAdminSearchParamDto.java <==
package com.rocogz.syy.order.dto.withdrawals;

import com.rocogz.syy.order.constant.OrderConstant;
import com.rocogz.syy.order.dto.AdminBaseSearchDto;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;

/**
 * 管理后台-> 提现订单 搜索 条件
 * @author ranxiangfu
 * @date 2020/8/4
 */
@Data
public class WithdrawalsAdminSearchParamDto extends AdminBaseSearchDto  {

    public WithdrawalsAdminSearchParamDto() {
        setOrderType(OrderConstant.DictOrderType.WITHDRAWALS_ORDER);
    }

    /**
     * 收款账户/卡号
     */
    private String account;

    /**
     * 提现状态: PENDIND-待审批; PENDING_PROCESS-(已受理/待处理); REFUSE-(未受理/审核不通过);
     *      PROCESSING-(转账中/处理中); SUCCESS-提现成功; FAIL-提现失败;
     */
    private String withdrawalsStatus;

    /**
     * 提现方式; ALIPAY:支付宝, BANK:银行账户
     */
    private String withdrawalsWay;

    /**
     * 身份证号码【模糊匹配】
     */
    private String idCard;

    /**
     * 收款人姓名 【模糊匹配】
     * 提现方式：如果是 ALIPAY（支付宝),则用id_name匹配
     * 提现方式：如果是 BANK（银行账户),则用bank_cardholder_name匹配
     */
    private String payeeName;

    /**
     * 收款人手机号码 【模糊匹配】
     */
    private String payeeMobile;

    /**
     * 更新时间起始
     */
    private String updateStartTime;

    /**
     * 更新时间结束
     */
    private String updateEndTime;

    //如果 maxCent!=null,则查询 积分 <= maxCent的提现订单
    private BigDecimal maxCent;


    /**
     * 选择结算账户后，转让订单信息列表：默认展示当前查询到该结算账户关联的符合以下条件的全部转让订单：
     *   1）【提现状态】是【待处理】
     *   2）【收款方式】是【银行卡】
     *
     * 结算账户编号
     */
    private String settleAcctCode;


    /**
     * 结算单号,如果传入了结算单号，则需要查询该结算单下所有的订单
     */
    private String billCode;



    public String getIdCardLike() {
        if(StringUtils.isBlank(idCard)) {
            return null;
        }
        return StringUtils.wrap(idCard,"%");
    }


    public String getPayeeMobileLike() {
        if(StringUtils.isBlank(payeeMobile)) {
            return null;
        }
        return StringUtils.wrap(payeeMobile,"%");
    }


    public String getPayeeNameLike() {
        if(StringUtils.isBlank(payeeName)) {
            return null;
        }
        return StringUtils.wrap(payeeName,"%");
    }

}
